{% extends "cow/base.html" %}

{% block content %}
<form class="pure-form" action="" method="post">{% csrf_token %}
    <p>Are you sure you want to delete {{ object }}?</p>
    <input class="pure-button pure-button-primary" type="submit" value="Delete" />
</form>
{% endblock %}
