{% extends "cow/base.html" %}

{% block content %}
<form class="pure-form" action="" method="post">{% csrf_token %}
    {{ form.as_p }}
    <input class="pure-button pure-button-primary" type="submit" value="Create" />
</form>
{% endblock %}
