{% extends "cow/base.html" %}

{% block head %}
{{ form.media }}
{% endblock %}

{% block content %}
<form class="pure-form" action="" method="post">{% csrf_token %}
    {{ form.as_p }}
    <input class="pure-button pure-button-primary" type="submit" value="Update" />
</form>
<script>
//tinymce.init({selector: '#id_content'});
tinymce.init({
  selector: '#id_content',
  height: 600,
  theme: 'modern',
  plugins: [
    'advlist autolink lists link image charmap print preview hr anchor pagebreak',
    'searchreplace wordcount visualblocks visualchars code fullscreen',
    'insertdatetime media nonbreaking save table contextmenu directionality',
    'emoticons template paste textcolor colorpicker textpattern imagetools codesample toc'
  ],
  toolbar1: 'undo redo | insert | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link image',
  toolbar2: 'print preview media | forecolor backcolor emoticons | codesample',
  image_advtab: true,
 });
</script>
{% endblock %}
